import { select, json, geoPath, geoMercator} from 'd3';
import {feature} from 'topojson';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

//initialize the spherical Mercator projection.
//scaling and aligning the map
const projection = d3.geoMercator().scale(125).translate([width/ 2, height / 1.7]) ;
//The spherical Mercator projection to the geopath library
const pathGenerator = geoPath().projection(projection);


//Create a spherical svg structure for the geo path
svg.append('path')
		.attr('class', 'sphere')
		.attr('d', pathGenerator({type: 'Sphere'}));


// Loading all countries data from gist
json('https://gist.githubusercontent.com/bhargavarathod/162731bd689791cc2fbb426652e7bb7e/raw/4d815bcc83d52268d9d1f6c83528ce17f036d624/world.json')
		.then(data => {
  			const countries = feature(data, data.objects.countries);
  
       //Create an svg file to load the countries' information into the path generator.
  			svg.selectAll('path')
        		.data(countries.features)
  					.enter().append('path')
  					.attr('class', 'country')
  					.attr('d', pathGenerator)
		});









